Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(263)

Unified Diff: chrome/browser/ui/views/tabs/browser_tab_strip_controller.h

Issue 291093005: Removes --enable-stacked-tab-strip flag (Stacked Tabs) (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Removes --enable-stacked-tab-strip flag (removed stale header) Created 6 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/tabs/browser_tab_strip_controller.h
diff --git a/chrome/browser/ui/views/tabs/browser_tab_strip_controller.h b/chrome/browser/ui/views/tabs/browser_tab_strip_controller.h
index 35e8940b612d84b2cc20916d65fed4398d22889d..22223e7fbf5d6cf64d1b6a16515797bebd4136f3 100644
--- a/chrome/browser/ui/views/tabs/browser_tab_strip_controller.h
+++ b/chrome/browser/ui/views/tabs/browser_tab_strip_controller.h
@@ -71,7 +71,7 @@ class BrowserTabStripController : public TabStripController,
virtual void CreateNewTab() OVERRIDE;
virtual void CreateNewTabWithLocation(const base::string16& loc) OVERRIDE;
virtual bool IsIncognito() OVERRIDE;
- virtual void LayoutTypeMaybeChanged() OVERRIDE;
+ virtual void StackedLayoutMaybeChanged() OVERRIDE;
virtual void OnStartedDraggingTabs() OVERRIDE;
virtual void OnStoppedDraggingTabs() OVERRIDE;
virtual void CheckFileSupported(const GURL& url) OVERRIDE;
@@ -137,8 +137,8 @@ class BrowserTabStripController : public TabStripController,
// Adds a tab.
void AddTab(content::WebContents* contents, int index, bool is_active);
- // Resets the tabstrips layout type from prefs.
- void UpdateLayoutType();
+ // Resets the tabstrips stacked layout (true or false) from prefs.
+ void UpdateStackedLayout();
// Notifies the tabstrip whether |url| is supported once a MIME type request
// has completed.
« no previous file with comments | « chrome/browser/ui/tabs/tab_strip_layout_type_prefs.cc ('k') | chrome/browser/ui/views/tabs/browser_tab_strip_controller.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698